@@ -41,10 +41,6 @@ class Puppet::Indirector::Request
     end
   end
 
-  def escaped_key
-    URI.escape(key)
-  end
-
   # LAK:NOTE This is a messy interface to the cache, and it's only
   # used by the Configurer class.  I decided it was better to implement
   # it now and refactor later, when we have a better design, than
@@ -97,7 +93,7 @@ class Puppet::Indirector::Request
   end
 
   def model
-    raise ArgumentError, "Could not find indirection '#{indirection_name}'" unless i = indirection
+    raise ArgumentError, _("Could not find indirection '%{indirection}'") % { indirection: indirection_name } unless i = indirection
     i.model
   end
 
@@ -133,17 +129,17 @@ class Puppet::Indirector::Request
       case value
       when nil
         params
-      when true, false, String, Symbol, Fixnum, Bignum, Float
+      when true, false, String, Symbol, Integer, Float
         params << [key, value]
       else
-        raise ArgumentError, "HTTP REST queries cannot handle values of type '#{value.class}'"
+        raise ArgumentError, _("HTTP REST queries cannot handle values of type '%{klass}'") % { klass: value.class }
       end
     end
   end
 
   def encode_params(params)
     params.collect do |key, value|
-      "#{key}=#{CGI.escape(value.to_s)}"
+      "#{key}=#{Puppet::Util.uri_query_encode(value.to_s)}"
     end.join("&")
   end
 
@@ -191,7 +187,7 @@ class Puppet::Indirector::Request
           self.port   = srv_port
           return yield(self)
         rescue SystemCallError => e
-          Puppet.warning "Error connecting to #{srv_server}:#{srv_port}: #{e.message}"
+          Puppet.warning _("Error connecting to %{srv_server}:%{srv_port}: %{message}") % { srv_server: srv_server, srv_port: srv_port, message: e.message }
         end
       end
     end
@@ -243,11 +239,10 @@ class Puppet::Indirector::Request
   def set_uri_key(key)
     @uri = key
     begin
-      # calling URI.escape for UTF-8 characters will % escape them
-      # and the resulting string components of the URI are now ASCII
-      uri = URI.parse(URI.escape(key))
+      # calling uri_encode for UTF-8 characters will % escape them and keep them UTF-8
+      uri = URI.parse(Puppet::Util.uri_encode(key))
     rescue => detail
-      raise ArgumentError, "Could not understand URL #{key}: #{detail}", detail.backtrace
+      raise ArgumentError, _("Could not understand URL %{key}: %{detail}") % { key: key, detail: detail }, detail.backtrace
     end
 
     # Just short-circuit these to full paths
@@ -274,8 +269,6 @@ class Puppet::Indirector::Request
       @protocol = uri.scheme
     end
 
-    # The unescaped bytes are correct but in ASCII and must be treated
-    # as UTF-8 for the sake of performing string comparisons later
-    @key = URI.unescape(uri.path.sub(/^\//, '')).force_encoding(Encoding::UTF_8)
+    @key = URI.unescape(uri.path.sub(/^\//, ''))
   end
 end
