@@ -15,7 +15,7 @@ class Puppet::InfoService::ClassInformationService
     # feature flags in effect.
 
     unless env_file_hash.is_a?(Hash)
-      raise ArgumentError, 'Given argument must be a Hash'
+      raise ArgumentError, _('Given argument must be a Hash')
     end
 
     result = {}
@@ -36,8 +36,7 @@ class Puppet::InfoService::ClassInformationService
   private
 
   def type_parser
-    # Safe to cache this as it would otherwise constantly build up the visitor cache
-    @@type_parser ||= Puppet::Pops::Types::TypeParser.new
+    Puppet::Pops::Types::TypeParser.singleton
   end
 
   def literal_evaluator
@@ -53,7 +52,7 @@ class Puppet::InfoService::ClassInformationService
   end
 
   def parse_file(f)
-    return {:error => "The file #{f} does not exist"} unless Puppet::FileSystem.exist?(f)
+    return {:error => _("The file %{f} does not exist") % { f: f }} unless Puppet::FileSystem.exist?(f)
 
     begin
       parse_result = @parser.parse_file(f)
@@ -106,7 +105,6 @@ class Puppet::InfoService::ClassInformationService
 
   # Extracts the source for the expression
   def extract_value_source(value_expr)
-    position = Puppet::Pops::Adapters::SourcePosAdapter.adapt(value_expr)
-    position.extract_tree_text
+    value_expr.locator.extract_tree_text(value_expr)
   end
-end
\ No newline at end of file
+end
