@@ -347,18 +347,25 @@ class AccessOperator
     end
   end
 
-  def access_PType(o, scope, keys)
+  def access_PTypeType(o, scope, keys)
     keys.flatten!
     if keys.size == 1
       unless keys[0].is_a?(Types::PAnyType)
         fail(Issues::BAD_TYPE_SLICE_TYPE, @semantic.keys[0], {:base_type => 'Type-Type', :actual => keys[0].class})
       end
-      Types::PType.new(keys[0])
+      Types::PTypeType.new(keys[0])
     else
       fail(Issues::BAD_TYPE_SLICE_ARITY, @semantic, {:base_type => 'Type-Type', :min => 1, :actual => keys.size})
     end
   end
 
+  def access_PInitType(o, scope, keys)
+    unless keys[0].is_a?(Types::PAnyType)
+      fail(Issues::BAD_TYPE_SLICE_TYPE, @semantic.keys[0], {:base_type => 'Init-Type', :actual => keys[0].class})
+    end
+    Types::TypeFactory.init(*keys)
+  end
+
   def access_PIterableType(o, scope, keys)
     keys.flatten!
     if keys.size == 1
@@ -618,7 +625,7 @@ class AccessOperator
 
   NS = '::'.freeze
 
-  def access_PHostClassType(o, scope, keys)
+  def access_PClassType(o, scope, keys)
     blamed = keys.size == 0 ? @semantic : @semantic.keys[0]
     keys_orig_size = keys.size
 
@@ -651,7 +658,7 @@ class AccessOperator
         name = name[2..-1] if name[0,2] == NS
 
         fail(Issues::ILLEGAL_NAME, @semantic.keys[i], {:name=>c}) unless name =~ Patterns::NAME
-        Types::PHostClassType.new(name)
+        Types::PClassType.new(name)
       end
     else
       # lookup class resource and return one or more parameter values
