@@ -18,7 +18,7 @@ class ModelLabelProvider
     @@label_visitor.visit_this_0(self, o)
   end
 
-  def label_Factory o                     ; label(o.current)                    end
+  def label_Factory o                     ; label(o.model)                      end
   def label_Array o                       ; "Array"                             end
   def label_LiteralInteger o              ; "Literal Integer"                   end
   def label_LiteralFloat o                ; "Literal Float"                     end
@@ -98,8 +98,11 @@ class ModelLabelProvider
   def label_TypeAlias o                   ; "Type Alias"                        end
   def label_TypeMapping o                 ; "Type Mapping"                      end
   def label_TypeDefinition o              ; "Type Definition"                   end
+  def label_Binary o                      ; "Binary"                            end
   def label_Application o                 ; "Application"                       end
   def label_Sensitive o                   ; "Sensitive"                         end
+  def label_Timestamp o                   ; "Timestamp"                         end
+  def label_Timespan o                    ; "Timespan"                          end
 
   def label_PResourceType o
     if o.title
@@ -119,7 +122,8 @@ class ModelLabelProvider
       simple_name = o.name.split('::').last
       simple_name[1..-5] + "-Type"
     else
-      o.name
+      n = o.name
+      n.nil? ? 'Anonymous Class' : n
     end
   end
 end
